Module: Resend
- Defined in:
- lib/resend.rb,
lib/resend/logs.rb,
lib/resend/batch.rb,
lib/resend/client.rb,
lib/resend/emails.rb,
lib/resend/errors.rb,
lib/resend/events.rb,
lib/resend/mailer.rb,
lib/resend/topics.rb,
lib/resend/domains.rb,
lib/resend/railtie.rb,
lib/resend/request.rb,
lib/resend/version.rb,
lib/resend/api_keys.rb,
lib/resend/contacts.rb,
lib/resend/response.rb,
lib/resend/segments.rb,
lib/resend/webhooks.rb,
lib/resend/templates.rb,
lib/resend/broadcasts.rb,
lib/resend/automations.rb,
lib/resend/contacts/topics.rb,
lib/resend/automations/runs.rb,
lib/resend/contacts/imports.rb,
lib/resend/emails/receiving.rb,
lib/resend/contacts/segments.rb,
lib/resend/multipart_request.rb,
lib/resend/pagination_helper.rb,
lib/resend/contact_properties.rb,
lib/resend/emails/attachments.rb,
lib/resend/emails/receiving/attachments.rb
Overview
Main Resend module
Defined Under Namespace
Modules: ApiKeys, Automations, Batch, Broadcasts, ContactProperties, Contacts, Domains, Emails, Events, Logs, Segments, Templates, Topics, Webhooks Classes: Client, Error, Mailer, MultipartRequest, PaginationHelper, Railtie, Request, Response
Constant Summary collapse
- Audiences =
Deprecated.
Use Segments instead
Segments- VERSION =
"1.5.0"- WEBHOOK_TOLERANCE_SECONDS =
The Webhooks module provides methods for managing webhooks via the Resend API. Webhooks allow you to receive real-time notifications about email events.
Default tolerance for timestamp validation (5 minutes)
300
Class Attribute Summary collapse
-
.api_key ⇒ Object
Returns the value of attribute api_key.
Class Method Summary collapse
- .configure {|_self| ... } ⇒ Object (also: config)
Class Attribute Details
.api_key ⇒ Object
Returns the value of attribute api_key.
46 47 48 |
# File 'lib/resend.rb', line 46 def api_key @api_key end |
Class Method Details
.configure {|_self| ... } ⇒ Object Also known as: config
48 49 50 51 |
# File 'lib/resend.rb', line 48 def configure yield self if block_given? true end |