Module: Resend

Defined in:
lib/resend.rb,
lib/resend/logs.rb,
lib/resend/batch.rb,
lib/resend/client.rb,
lib/resend/emails.rb,
lib/resend/errors.rb,
lib/resend/events.rb,
lib/resend/mailer.rb,
lib/resend/topics.rb,
lib/resend/domains.rb,
lib/resend/railtie.rb,
lib/resend/request.rb,
lib/resend/version.rb,
lib/resend/api_keys.rb,
lib/resend/contacts.rb,
lib/resend/response.rb,
lib/resend/segments.rb,
lib/resend/webhooks.rb,
lib/resend/templates.rb,
lib/resend/broadcasts.rb,
lib/resend/automations.rb,
lib/resend/contacts/topics.rb,
lib/resend/automations/runs.rb,
lib/resend/emails/receiving.rb,
lib/resend/contacts/segments.rb,
lib/resend/pagination_helper.rb,
lib/resend/contact_properties.rb,
lib/resend/emails/attachments.rb,
lib/resend/emails/receiving/attachments.rb

Overview

Main Resend module

Defined Under Namespace

Modules: ApiKeys, Automations, Batch, Broadcasts, ContactProperties, Contacts, Domains, Emails, Events, Logs, Segments, Templates, Topics, Webhooks Classes: Client, Error, Mailer, PaginationHelper, Railtie, Request, Response

Constant Summary collapse

Audiences =
Deprecated.

Use Segments instead

Segments
VERSION =
"1.4.0"
WEBHOOK_TOLERANCE_SECONDS =

The Webhooks module provides methods for managing webhooks via the Resend API. Webhooks allow you to receive real-time notifications about email events.

Default tolerance for timestamp validation (5 minutes)

300

Class Attribute Summary collapse

Class Method Summary collapse

Class Attribute Details

.api_keyObject

Returns the value of attribute api_key.



44
45
46
# File 'lib/resend.rb', line 44

def api_key
  @api_key
end

Class Method Details

.configure {|_self| ... } ⇒ Object Also known as: config

Yields:

  • (_self)

Yield Parameters:

  • _self (Resend)

    the object that the method was called on



46
47
48
49
# File 'lib/resend.rb', line 46

def configure
  yield self if block_given?
  true
end